#
# spec file for package tempo-cli
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tempo-cli
Version:        2.7.0
Release:        1.1
Summary:        CLI for the Grafana Tempo tracing backend
License:        Apache-2.0
URL:            https://github.com/grafana/tempo
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz

BuildRequires:  go >= 1.23.3

%description
Tempo CLI is a separate executable that contains utility functions related to
the Tempo software. Although it is not required for a working installation,
Tempo CLI can be helpful for deeper analysis or for troubleshooting.

%prep
%autosetup -p 1 -a 1

%build
# hash will be shortended by COMMIT_HASH:0:8 later
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X main.Branch=v%{version} \
   -X main.Revision=${COMMIT_HASH:0:8} \
   -X main.Version=%{version}" \
   -o bin/%{name} ./cmd/%{name}

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

%check

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Tue Jan 14 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.7.0:
  Please check the full changelog for the breaking changes:
  https://github.com/grafana/tempo/releases/tag/v2.7.0
  CLI-related changes:
  * [release-v2.7] Changelog cleanup 2.7.0 (#4544)
  * [DOC] Add clarification for metrics summary and traceQL metrics
    (#4316)
  * tempo-cli: support dropping multiple traces in a single
    operation (#4266)
  * docs: Remove duplicated examples (#4295)
  * docs: mark serverless as deprecated (#4017)
  * docs: Update readme with explore traces info (#4263)
  * Docs: fix trace:rootService example code (#4265)
  * doc: correct traceQL metrics documentation (#4252)
  * Fix tempo cli arguments (#4259)
  * [DOC] Update metrics query docs with examples, more details
    (#4248)
  * [DOC] Update local-block processor config for 2.6 changes
    (#4223)
  * [DOC] Add 2.6.1 breaking change to Upgrade page (#4215)
  * [DOC] Add deprecation for metrics summary (#4193)
  * [DOC] Fix wrong date command in push HTTP API doc (#4206)
  * [DOC] Remove traceQLStreaming feature flag (#4188)
  * [DOC] Add 2.6.1 to release notes (#4191)
  * [DOC] Update statement for metrics-generator for Cloud (#4151)
  * [DOC] Update metrics for Alloy troubleshooting doc (#4137)
  * [docs] use proper default value for grpc server message size
    (#4133)
  * [DOC] Clarify Parquet requirements in 2.6 (#4135)
  * tempo-cli: add support for /api/v2/traces endpoint (#4127)
  * [DOC] Add other attributes to trace structure doc (#4106)
  * Fix cli analyse block dedicated text output (#4055)
  * [DOC] Release notes for 2.6 (#4048)
  * [DOC] TraceQL, metrics-gen, and overrides doc updates for 2.6
    (#4041)
  * [DOC] Convert monitor, troubleshoot, set up test app to Alloy
    (#4026)
  * [DOC] Add vParquet4 to analyse blocks CLI and update parquet
    doc (#4033)
  * [Doc] Update retrieve traces  doc to use Traces V2 (#4037)
  * [DOC] Add doc for compare function for metrics doc (#4024)
  * [DOC] Update query editor content and screenshots (#3986)
  * [DOC] operator: clarify supported Kubernetes versions (#4019)
  * [DOC] Correct Jaeger spelling mistake (#4015)
  * [cli] add jsonnet support to analyse blocks (#4012)
* Wed Oct 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.6.1:
  * tempo-query: register gRPC health server (#4178) (#4186)
  * [release-v2.6]  Support Tempo on IBM s390x  (#4185)
  * fix: bring back content-type header (#4123) (#4184)
  * tempo-query: separate tls settings for server and client
    (#4177) (#4183)
  * [release-v2.6] docs: Add EKS Pod Identity as supported (#4174)
  * Backport tempo-query changes to 2.6 (#4170)
  * [release-v2.6] [DOC] Fix broken links in Alloy docs (#4169)
  * [release-v2.6] [DOC] Update statement for metrics-generator for
    Cloud (#4164)
  * [release-v2.6] Fix typo in gcs configuration comment (#4150)
  * [release-v2.6] Fixed a small typo in Tempo set up documentation
    (#4145)
  * [release-v2.6] [DOC] Add other attributes to trace structure
    doc (#4108)
  * [release-v2.6] Update and remove old images in Linux set up doc
    (#4071)
  * [release-v2.6] docs: Getting started sandbox (#4070)
  * [release-v2.6] Add blog post links to rel notes (#4059)
  * [release-v2.6] [DOC] TraceQL, metrics-gen, and overrides doc
    updates for 2.6 (#4054)
  * Use canonical centering an image example (#4043) (#4051)
  * [release-v2.6] [DOC] Release notes for 2.6 (#4050)
  * [release-v2.6] [DOC] Convert monitor, troubleshoot, set up test
    app to Alloy (#4049)
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.6.0:
  https://github.com/grafana/tempo/releases/tag/v2.6.0
  CLI-related changes:
  * [ENHANCEMENT] Added a Tempo CLI command to drop traces by id by
    rewriting blocks. #3856 (@joe-elliott)
  * [ENHANCEMENT] Add vParquet4 support to the tempo-cli analyse
    blocks command #3868 (@stoewer)
  * [ENHANCEMENT] Expose availability-zone as a cli flag in
    ingester #3881
* Sat Jun  1 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.5.0:
  https://github.com/grafana/tempo/releases/tag/v2.5.0
  CLI-related changes:
  * [ENHANCEMENT] Tempo CLI - add percentage support for query
    blocks #3697 #3697 (@edgarkz)
* Sat May 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.4.2:
  * Pin the goreleaser version for Go version support (#3674)
  * Bump x/net package to 0.24/latest (#3614)
  * [release-v2.4] Update set-up-monitoring.md (#3625)
  * [release-v2.4] Remove incorrect query (#3608)
  * [release-v2.4] [DOC] Revised Tune search performance doc
    (#3595)
  * [release-v2.4] [DOC] Fix linter-related issues (#3581)
  * [release-v2.4] Replace ß with s (#3578)
  * [release-v2.4] [DOC] Add note for Grafana Alloy (#3565)
  * [release-v2.4] [DOC] Update monitoring doc (#3550)
  * [release-v2.4] Fix a broken link in tail-based-sampling.md
    (#3545)
  * [release-v2.4] [DOC] Tempo landing page for docs (#3549)
  * [release-v2.4] Outdated documentation setting up a test app
    (#3533)
  * [release-v2.4] [DOC] Add 2.4.1 release notes (#3518)
  * [release-v2.4] [DOC] Document Tempo Operator Monolithic mode
    (#3519)
  * [release-v2.4] [DOC] document Grafana data source setup using
    Grafana and Tempo operators (#3520)
  * [release-v2.4] Doc update (#3521)
* Mon Apr  8 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package tempo-cli: CLI for the Grafana Tempo tracing backend
